@@ -525,10 +525,17 @@ Hops:
 
   def compression_params(self, mip):
     encoding = self.encoding(mip)
+    scale = self.scale(mip)
     if encoding == 'zfpc':
       return self.zfpc_encoding_params(mip)
     elif encoding == 'compressed_segmentation':
       return { "block_size": self.compressed_segmentation_block_size(mip) }
+    elif encoding == 'png':
+      return { "level": scale.get("png_level", None) }
+    elif encoding == 'jpeg':
+      return { "level": scale.get("jpeg_quality", None) }
+    elif encoding == 'fpzip':
+      return { "level": scale.get("fpzip_precision", None) }
     else:
       return {}
 
@@ -653,15 +660,26 @@ Hops:
     """Used for manually resetting downsamples if something messed up."""
     self.info['scales'] = self.info['scales'][0:1]
 
-  def add_resolution(self, res, encoding=None, chunk_size=None, info=None):
+  def add_resolution(
+    self, res, encoding=None, 
+    chunk_size=None, info=None,
+    encoding_level=None,
+  ):
     if lib.floating(res):
       factor = Vec(*res, dtype=float) / self.resolution(0)
     else:
       factor = Vec(*res) // self.resolution(0)
 
-    return self.add_scale(factor, encoding, chunk_size, info)
+    return self.add_scale(
+      factor, encoding, chunk_size, info, 
+      encoding_level=encoding_level
+    )
 
-  def add_scale(self, factor, encoding=None, chunk_size=None, info=None):
+  def add_scale(
+    self, factor, 
+    encoding=None, chunk_size=None, info=None,
+    encoding_level=None,
+  ):
     """
     Generate a new downsample scale to for the info file and return an updated dictionary.
     You'll still need to call self.commit_info() to make it permenant.
@@ -710,6 +728,14 @@ Hops:
       u"size": downscale(fullres['size'], factor, np.ceil),
     }
 
+    if encoding_level is not None:
+      if encoding == "jpeg":
+        newscale["jpeg_quality"] = int(encoding_level)
+      elif encoding == "png":
+        newscale["png_level"] = int(encoding_level)
+      elif encoding == "fpzip":
+        newscale["fpzip_precision"] = int(encoding_level)
+
     if newscale['encoding'] == 'compressed_segmentation':
       if 'compressed_segmentation_block_size' in fullres:
         newscale['compressed_segmentation_block_size'] = fullres['compressed_segmentation_block_size']  
