@@ -1,4 +1,4 @@
-from __future__ import print_function
+from typing import Optional, Sequence
 
 import itertools
 import gevent.socket
@@ -20,13 +20,12 @@ from ..cacheservice import CacheService
 from .. import exceptions 
 from ..lib import ( 
   colorize, red, mkdir, 
-  Vec, Bbox, jsonify
+  Vec, Bbox, jsonify, BboxLikeType,
 )
 
 from ..datasource import autocropfn
 from ..datasource.precomputed import PrecomputedMetadata
 
-from ..paths import strict_extract
 from ..provenance import DataLayerProvenance
 from ..storage import SimpleStorage, Storage, reset_connection_pools
 from ..volumecutout import VolumeCutout
@@ -529,16 +528,139 @@ class CloudVolumePrecomputed(object):
     img = self.download(requested_bbox, self.mip)
     return img[::steps.x, ::steps.y, ::steps.z, channel_slice]
 
-  def download(
-      self, bbox, mip=None, parallel=None,
-      segids=None, preserve_zeros=False,
-      
-      # Absorbing polymorphic Graphene calls
-      agglomerate=None, timestamp=None, stop_layer=None,
+  def unique(
+    self, 
+    bbox:BboxLikeType, 
+    mip:Optional[int] = None,
+    
+    # Absorbing polymorphic Graphene calls
+    agglomerate:Optional[bool] = None, 
+    timestamp:Optional[int] = None, 
+    stop_layer:Optional[int] = None,
 
-      # new download arguments
-      renumber=False
-    ):
+    # new download arguments
+    coord_resolution:Optional[Sequence[int]] = None,
+  ):
+    """
+    Downloads segmentation and extracts unique
+    labels from it without rendering a full image.
+    Faster and saves memory.
+    """
+    bbox = Bbox.create(
+      bbox, context=self.bounds, 
+      bounded=(self.bounded and coord_resolution is None), 
+      autocrop=self.autocrop
+    )
+
+    if mip is None:
+      mip = self.mip
+
+    if coord_resolution is not None:
+      factor = self.meta.resolution(mip) / coord_resolution
+      bbox /= factor
+      if self.bounded and not self.meta.bounds(mip).contains_bbox(bbox):
+        raise exceptions.OutOfBoundsError(f"Computed {bbox} is not contained within bounds {self.meta.bounds(mip)}")
+
+    return self.image.unique(
+      bbox.astype(np.int64), mip
+    )
+
+  def download_files(
+    self,
+    bbox:BboxLikeType, 
+    mip:Optional[int] = None, 
+    parallel:Optional[int] = None,
+    segids:Optional[Sequence[int]] = None, 
+    
+    # Absorbing polymorphic Graphene calls
+    agglomerate:Optional[bool] = None, 
+    timestamp:Optional[int] = None, 
+    stop_layer:Optional[int] = None,
+
+    coord_resolution:Optional[Sequence[int]] = None,
+    cache_only:bool = False,
+    decompress:bool = True,
+  ):
+    """
+    Downloads files without rendering to an image.
+
+    decompress: automatically decompress downloaded
+      files. If False, returns the raw bytes.
+    cache_only: discard downloaded files to avoid
+      inflating memory. (you must enable the cache separately)
+
+    Returns: { filename: binary }
+    """
+    bbox = Bbox.create(
+      bbox, context=self.bounds, 
+      bounded=(self.bounded and coord_resolution is None), 
+      autocrop=self.autocrop
+    )
+
+    if mip is None:
+      mip = self.mip
+
+    if coord_resolution is not None:
+      factor = self.meta.resolution(mip) / coord_resolution
+      bbox /= factor
+      if self.bounded and not self.meta.bounds(mip).contains_bbox(bbox):
+        raise exceptions.OutOfBoundsError(f"Computed {bbox} is not contained within bounds {self.meta.bounds(mip)}")
+
+    if parallel is None:
+      parallel = self.parallel
+
+    files = self.image.download_files(
+      bbox.astype(np.int64), mip, 
+      parallel=parallel,
+      decompress=decompress, 
+      cache_only=cache_only
+    )
+
+    if not segids:
+      return files
+
+    for key in files:
+      val = files[key]
+      labels = set(chunks.labels(val))
+      mask_labels = labels - set(segids)
+      remap = { lbl: lbl for lbl in segids }
+      if preserve_zeros:
+        mask_value = np.inf
+        if np.issubdtype(self.dtype, np.integer):
+          mask_value = np.iinfo(self.dtype).max        
+      remap.update({ mask_labels: mask_value for lbl in mask_labels })
+      if preserve_zeros:
+        remap[0] = 0
+
+      files[key] = chunks.remap(
+        files[key], 
+        encoding=self.meta.encoding(mip), 
+        shape=self.meta.chunk_size(mip),
+        dtype=self.meta.dtype,
+        block_size=self.meta.compressed_segmentation_block_size(mip),
+        mapping=remap,
+        preserve_missing_labels=True,
+      )
+
+    return files
+    
+  def download(
+    self, 
+    bbox:BboxLikeType, 
+    mip:Optional[int] = None, 
+    parallel:Optional[int] = None,
+    segids:Optional[Sequence[int]] = None, 
+    preserve_zeros:bool = False,
+    
+    # Absorbing polymorphic Graphene calls
+    agglomerate:Optional[bool] = None, 
+    timestamp:Optional[int] = None, 
+    stop_layer:Optional[int] = None,
+
+    # new download arguments
+    renumber:bool = False, 
+    coord_resolution:Optional[Sequence[int]] = None,
+  ) -> VolumeCutout:
     """
     Downloads segmentation from the indicated cutout
     region.
@@ -556,6 +678,9 @@ class CloudVolumePrecomputed(object):
     renumber: dynamically rewrite downloaded segmentation into
       a more compact data type. Only compatible with single-process
       non-sharded download.
+    coord_resolution: (rx,ry,rz) the coordinate resolution of the input point.
+      Sometimes Neuroglancer is working in the resolution of another
+      higher res layer and this can help correct that.
 
     agglomerate, timestamp, and stop_layer are just there to 
     absorb arguments to what could be a graphene frontend.
@@ -564,13 +689,19 @@ class CloudVolumePrecomputed(object):
     """  
     bbox = Bbox.create(
       bbox, context=self.bounds, 
-      bounded=self.bounded, 
+      bounded=(self.bounded and coord_resolution is None), 
       autocrop=self.autocrop
     )
 
     if mip is None:
       mip = self.mip
 
+    if coord_resolution is not None:
+      factor = self.meta.resolution(mip) / coord_resolution
+      bbox /= factor
+      if self.bounded and not self.meta.bounds(mip).contains_bbox(bbox):
+        raise exceptions.OutOfBoundsError(f"Computed {bbox} is not contained within bounds {self.meta.bounds(mip)}")
+
     if parallel is None:
       parallel = self.parallel
 
